Gets league-play data for each game, from engsoccerdata, returning a tibble in a standardised format.
Usage
uss_get_matches(country = uss_countries(), ...)Arguments
- country
characterscalar, specifies the league.- ...
<
data-masking> Expressions that return a logical value, and are defined in terms of the variables in.data. If multiple expressions are included, they are combined with the&operator. Only rows for which all conditions evaluate toTRUEare kept.
Details
uss_countries() returns the available choices; "england" is
the default.
This function relies on an internal function, uss_make_matches(), to parse
the source data.
Examples
uss_get_matches("england")
#> # A tibble: 192,004 × 8
#> country tier season date home visitor goals…¹ goals…²
#> <chr> <fct> <int> <date> <chr> <chr> <int> <int>
#> 1 England 1 1888 1888-12-15 Accrington F.C. Aston Villa 1 1
#> 2 England 1 1888 1889-01-19 Accrington F.C. Blackburn Ro… 0 2
#> 3 England 1 1888 1889-03-23 Accrington F.C. Bolton Wande… 2 3
#> 4 England 1 1888 1888-12-01 Accrington F.C. Burnley 5 1
#> 5 England 1 1888 1888-10-13 Accrington F.C. Derby County 6 2
#> 6 England 1 1888 1888-12-29 Accrington F.C. Everton 3 1
#> 7 England 1 1888 1889-01-26 Accrington F.C. Notts County 1 2
#> 8 England 1 1888 1888-10-20 Accrington F.C. Preston Nort… 0 0
#> 9 England 1 1888 1889-04-20 Accrington F.C. Stoke City 2 0
#> 10 England 1 1888 1888-11-24 Accrington F.C. West Bromwic… 2 1
#> # … with 191,994 more rows, and abbreviated variable names ¹goals_home,
#> # ²goals_visitor
#> # ℹ Use `print(n = ...)` to see more rows
uss_get_matches("england", season == 1929)
#> # A tibble: 1,848 × 8
#> country tier season date home visitor goals_home goals_…¹
#> <chr> <fct> <int> <date> <chr> <chr> <int> <int>
#> 1 England 1 1929 1930-05-03 Arsenal Aston Villa 2 4
#> 2 England 1 1929 1930-03-15 Arsenal Birmingham City 1 0
#> 3 England 1 1929 1930-03-29 Arsenal Blackburn Rovers 4 0
#> 4 England 1 1929 1929-09-28 Arsenal Bolton Wanderers 1 2
#> 5 England 1 1929 1929-09-14 Arsenal Burnley 6 1
#> 6 England 1 1929 1929-10-12 Arsenal Derby County 1 1
#> 7 England 1 1929 1930-02-08 Arsenal Everton 4 0
#> 8 England 1 1929 1929-10-19 Arsenal Grimsby Town 4 1
#> 9 England 1 1929 1929-12-14 Arsenal Huddersfield Town 2 0
#> 10 England 1 1929 1929-08-31 Arsenal Leeds United 4 0
#> # … with 1,838 more rows, and abbreviated variable name ¹goals_visitor
#> # ℹ Use `print(n = ...)` to see more rows