Get a league-play tibble
uss_get_matches.RdGets league-play data for each game, from engsoccerdata, returning a tibble in a standardised format.
Usage
uss_get_matches(country = uss_countries(), ...)Arguments
- country
characterscalar, specifies the league.uss_countries()returns choices available from engsoccerdata- ...
<
data-masking> Expressions that return a logical value, and are defined in terms of the variables in.data. If multiple expressions are included, they are combined with the&operator. Only rows for which all conditions evaluate toTRUEare kept.
Value
tibble with columns country, date,
season, tier, home, visitor, goals_home, goals_visitor.
Details
uss_countries() returns the available choices; "england" is
the default. You can add filtering expressions via the ... argument;
These are evaluated using dplyr::filter().
This function relies on an internal function, uss_make_matches(), to parse
the source data.
Examples
uss_get_matches("england")
#> # A tibble: 192,004 × 8
#> country tier season date home visitor goals…¹ goals…²
#> <chr> <fct> <int> <date> <chr> <chr> <int> <int>
#> 1 England 1 1888 1888-12-15 Accrington F.C. Aston Villa 1 1
#> 2 England 1 1888 1889-01-19 Accrington F.C. Blackburn Ro… 0 2
#> 3 England 1 1888 1889-03-23 Accrington F.C. Bolton Wande… 2 3
#> 4 England 1 1888 1888-12-01 Accrington F.C. Burnley 5 1
#> 5 England 1 1888 1888-10-13 Accrington F.C. Derby County 6 2
#> 6 England 1 1888 1888-12-29 Accrington F.C. Everton 3 1
#> 7 England 1 1888 1889-01-26 Accrington F.C. Notts County 1 2
#> 8 England 1 1888 1888-10-20 Accrington F.C. Preston Nort… 0 0
#> 9 England 1 1888 1889-04-20 Accrington F.C. Stoke City 2 0
#> 10 England 1 1888 1888-11-24 Accrington F.C. West Bromwic… 2 1
#> # … with 191,994 more rows, and abbreviated variable names ¹goals_home,
#> # ²goals_visitor
#> # ℹ Use `print(n = ...)` to see more rows
uss_get_matches("italy", season == 1990)
#> # A tibble: 306 × 8
#> country tier season date home visitor goals…¹ goals…²
#> <chr> <fct> <int> <date> <chr> <chr> <int> <int>
#> 1 Italy 1 1990 1990-09-09 Parma AC Juventus 1 2
#> 2 Italy 1 1990 1990-09-09 Torino FC Lazio Roma 0 0
#> 3 Italy 1 1990 1990-09-09 Sampdoria AC Cesena 1 0
#> 4 Italy 1 1990 1990-09-09 AS Roma ACF Fiorenti… 4 0
#> 5 Italy 1 1990 1990-09-09 US Lecce SSC Napoli 0 0
#> 6 Italy 1 1990 1990-09-09 Cagliari Calcio Inter 0 3
#> 7 Italy 1 1990 1990-09-09 Bologna FC Pisa SC 0 1
#> 8 Italy 1 1990 1990-09-09 Atalanta AS Bari 2 0
#> 9 Italy 1 1990 1990-09-09 AC Milan Genoa CFC 1 0
#> 10 Italy 1 1990 1990-09-16 Genoa CFC AS Roma 3 0
#> # … with 296 more rows, and abbreviated variable names ¹goals_home,
#> # ²goals_visitor
#> # ℹ Use `print(n = ...)` to see more rows