Skip to contents

Gets league-play data for each game, from engsoccerdata, returning a tibble in a standardised format.

Usage

uss_get_matches(country = uss_countries(), ...)

Arguments

country

Name of country

...

<data-masking> Expressions that return a logical value, and are defined in terms of the variables in .data. If multiple expressions are included, they are combined with the & operator. Only rows for which all conditions evaluate to TRUE are kept.

Value

dataframe

Details

uss_countries() returns the available choices; "england" is the default. You may pass items to filter().

This function relies on an internal function, uss_make_matches(), to parse the source data.

Examples

uss_get_matches("england")
#> # A tibble: 192,004 × 8
#>    country tier  season date       home            visitor       goals…¹ goals…²
#>    <chr>   <fct>  <int> <date>     <chr>           <chr>           <int>   <int>
#>  1 England 1       1888 1888-12-15 Accrington F.C. Aston Villa         1       1
#>  2 England 1       1888 1889-01-19 Accrington F.C. Blackburn Ro…       0       2
#>  3 England 1       1888 1889-03-23 Accrington F.C. Bolton Wande…       2       3
#>  4 England 1       1888 1888-12-01 Accrington F.C. Burnley             5       1
#>  5 England 1       1888 1888-10-13 Accrington F.C. Derby County        6       2
#>  6 England 1       1888 1888-12-29 Accrington F.C. Everton             3       1
#>  7 England 1       1888 1889-01-26 Accrington F.C. Notts County        1       2
#>  8 England 1       1888 1888-10-20 Accrington F.C. Preston Nort…       0       0
#>  9 England 1       1888 1889-04-20 Accrington F.C. Stoke City          2       0
#> 10 England 1       1888 1888-11-24 Accrington F.C. West Bromwic…       2       1
#> # … with 191,994 more rows, and abbreviated variable names ¹​goals_home,
#> #   ²​goals_visitor
#> # ℹ Use `print(n = ...)` to see more rows
uss_get_matches("italy", season == 1960)
#> # A tibble: 306 × 8
#>    country tier  season date       home              visitor     goals…¹ goals…²
#>    <chr>   <fct>  <int> <date>     <chr>             <chr>         <int>   <int>
#>  1 Italy   1       1960 1960-09-25 Udinese Calcio    Juventus          0       1
#>  2 Italy   1       1960 1960-09-25 Torino FC         Sampdoria         0       1
#>  3 Italy   1       1960 1960-09-25 AC Milan          Calcio Cat…       3       0
#>  4 Italy   1       1960 1960-09-25 SPAL 1907 Ferrara Calcio Pad…       1       1
#>  5 Italy   1       1960 1960-09-25 Lanerossi Vicenza SSC Napoli        2       3
#>  6 Italy   1       1960 1960-09-25 ACF Fiorentina    Calcio Lec…       4       0
#>  7 Italy   1       1960 1960-09-25 Atalanta          Inter             1       5
#>  8 Italy   1       1960 1960-09-25 AS Bari           AS Roma           0       3
#>  9 Italy   1       1960 1960-09-25 Lazio Roma        Bologna FC        1       3
#> 10 Italy   1       1960 1960-10-02 Inter             AS Bari           2       1
#> # … with 296 more rows, and abbreviated variable names ¹​goals_home,
#> #   ²​goals_visitor
#> # ℹ Use `print(n = ...)` to see more rows